@@ -1,6 +1,6 @@
 from .table import Table
 from .column import (Column, LabelColumn, HrefColumn,
                      TemplateColumn, CheckboxColumn,
-                     DateTimeColumn,
+                     DateTimeColumn, DateColumn,
                      MoneyColumn, InlineTemplateColumn)
 from . import plugins
